diff --git a/collects/compiler/private/driver.rkt b/collects/compiler/private/driver.rkt index ca7444575a..127e069025 100644 --- a/collects/compiler/private/driver.rkt +++ b/collects/compiler/private/driver.rkt @@ -504,7 +504,7 @@ (printf (string-append " please report the bug using Help Desk~n" - " or http://bugs.plt-scheme.org/~n" + " or http://bugs.racket-lang.org/~n" " and include a transcript in verbose mode~n"))))) msgs) diff --git a/collects/drracket/private/app.rkt b/collects/drracket/private/app.rkt index 09e90e3bfe..ded05e7aef 100644 --- a/collects/drracket/private/app.rkt +++ b/collects/drracket/private/app.rkt @@ -165,7 +165,7 @@ (send e insert " by ") - (insert-url/external-browser "PLT" "http://www.plt-scheme.org/") + (insert-url/external-browser "PLT" "http://racket-lang.org/") (send* e (insert ".\n\n") @@ -361,7 +361,7 @@ (λ (x y) (send-url url)))))]) (add (string-constant drscheme-homepage) "http://www.drscheme.org/") - (add (string-constant plt-homepage) "http://www.plt-scheme.org/") + (add (string-constant plt-homepage) "http://racket-lang.org/") (add (string-constant teachscheme!-homepage) "http://www.teach-scheme.org/") (add (string-constant how-to-design-programs) "http://www.htdp.org/") diff --git a/collects/drracket/private/debug.rkt b/collects/drracket/private/debug.rkt index c07351a18b..a918b09ee7 100644 --- a/collects/drracket/private/debug.rkt +++ b/collects/drracket/private/debug.rkt @@ -360,7 +360,7 @@ profile todo: (make-url "http" #f - "planet.plt-scheme.org" + "planet.racket-lang.org" #f #t (list (make-path/param "trac" '()) diff --git a/collects/handin-client/handin-multi.rkt b/collects/handin-client/handin-multi.rkt index ca198a6d06..3939b94669 100644 --- a/collects/handin-client/handin-multi.rkt +++ b/collects/handin-client/handin-multi.rkt @@ -5,7 +5,7 @@ (define handin-name (#%info-lookup 'name)) (define web-address (#%info-lookup 'web-address - (lambda () "http://www.plt-scheme.org"))) + (lambda () "http://racket-lang.org"))) (define selection-mode (#%info-lookup 'selection-mode (lambda () 'extended))) (define selection-defaults (let ([sd (#%info-lookup 'selection-default (lambda () '("*.scm" "*.ss")))]) diff --git a/collects/help/bug-report.rkt b/collects/help/bug-report.rkt index 0b7c01250c..0fda138a14 100644 --- a/collects/help/bug-report.rkt +++ b/collects/help/bug-report.rkt @@ -15,7 +15,7 @@ (provide help-desk:report-bug) - (define bug-www-server "bugs.plt-scheme.org") + (define bug-www-server "bugs.racket-lang.org") (define bug-www-server-port 80) ;; this one should be defined by help desk. diff --git a/collects/help/search.rkt b/collects/help/search.rkt index b83c3c3db2..4cfb6dd489 100644 --- a/collects/help/search.rkt +++ b/collects/help/search.rkt @@ -21,7 +21,7 @@ ;; running a browser on local files (like NEU). If you use this, then ;; it is a good idea to put the documentation tree somewhere local, to ;; have better interaction times and not overload the PLT server. -;; (define doc-url "http://download.plt-scheme.org/doc/4.1/html/") +;; (define doc-url "http://download.racket-lang.org/doc/4.1/html/") ;; (define (send-main-page #:sub [sub "index.html"] ;; #:fragment [fragment #f] #:query [query #f]) ;; (define (part pfx x) (if x (list pfx x) '())) diff --git a/collects/meta/build/build b/collects/meta/build/build index b6af30a4f0..129496a766 100755 --- a/collects/meta/build/build +++ b/collects/meta/build/build @@ -890,7 +890,7 @@ html_begin() { # inputs: title [output-name] echo "
"
- echo " ![]() ![]() | "
echo " "
echo " "
diff --git a/collects/meta/build/nsis/plt-installer.nsi b/collects/meta/build/nsis/plt-installer.nsi
index 7adf687b72..1caf446a5c 100644
--- a/collects/meta/build/nsis/plt-installer.nsi
+++ b/collects/meta/build/nsis/plt-installer.nsi
@@ -54,8 +54,8 @@ InstallDir "$PROGRAMFILES\${PLTDirName}"
!define MUI_FINISHPAGE_RUN "$INSTDIR\DrScheme.exe"
!define MUI_FINISHPAGE_RUN_TEXT "Run DrScheme"
!endif
-!define MUI_FINISHPAGE_LINK "Visit the PLT Scheme web site"
-!define MUI_FINISHPAGE_LINK_LOCATION "http://www.plt-scheme.org/"
+!define MUI_FINISHPAGE_LINK "Visit the Racket web site"
+!define MUI_FINISHPAGE_LINK_LOCATION "http://racket-lang.org/"
; !define MUI_UNFINISHPAGE_NOAUTOCLOSE ; to allow users see what was erased
@@ -221,8 +221,8 @@ Section ""
WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PLTRegName}" "DisplayIcon" "$INSTDIR\DrScheme.exe,0"
WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PLTRegName}" "DisplayVersion" "${PLTVersion}"
; used to also have "VersionMajor" & "VersionMinor" but looks like it's not needed
- WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PLTRegName}" "HelpLink" "http://www.plt-scheme.org/"
- WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PLTRegName}" "URLInfoAbout" "http://www.plt-scheme.org/"
+ WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PLTRegName}" "HelpLink" "http://racket-lang.org/"
+ WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PLTRegName}" "URLInfoAbout" "http://racket-lang.org/"
WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PLTRegName}" "Publisher" "PLT Scheme Inc."
WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PLTRegName}" "NoModify" "1"
WriteRegDWORD HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PLTRegName}" "NoRepair" "1"
diff --git a/collects/meta/build/readme-specs b/collects/meta/build/readme-specs
index bc73068d32..314cc93941 100644
--- a/collects/meta/build/readme-specs
+++ b/collects/meta/build/readme-specs
@@ -130,8 +130,8 @@ more-information
:= "More Information" \\
"----------------" \\
\\
- "For further information, use DrScheme's `Help' menu, or run "plt-help*". "
- "Also, visit http://www.plt-scheme.org/." \\
+ "For further information, use DrRacket's `Help' menu, or run "plt-help*". "
+ "Also, visit http://racket-lang.org/." \\
readme
:= intro \\ main \\ \\ license \\ \\ more-information
diff --git a/collects/mzlib/zip.rkt b/collects/mzlib/zip.rkt
index e04296c1dd..b404e6e6ac 100644
--- a/collects/mzlib/zip.rkt
+++ b/collects/mzlib/zip.rkt
@@ -26,7 +26,7 @@
(define *spec-version* 62) ; version 6.2
(define *required-version* 20) ; version 2.0
(define *compression-level* 8) ; I don't think this is configurable
- (define *zip-comment* #"packed by PLT Scheme - http://www.plt-scheme.org/")
+ (define *zip-comment* #"packed by Racket - http://racket-lang.org/")
;; PKZIP specification:
;; http://www.pkware.com/company/standards/appnote/
diff --git a/collects/net/scribblings/url.scrbl b/collects/net/scribblings/url.scrbl
index 56f6e2af0c..bbdcbb90f9 100644
--- a/collects/net/scribblings/url.scrbl
+++ b/collects/net/scribblings/url.scrbl
@@ -69,9 +69,9 @@ adjusts the behavior.
An empty string at the end of the @scheme[path] list corresponds to a
URL that ends in a slash. For example, the result of
-@scheme[(string->url "http://www.drscheme.org/a/")] has a
+@scheme[(string->url "http://racket-lang.org/a/")] has a
@scheme[path] field with strings @scheme["a"] and @scheme[""], while
-the result of @scheme[(string->url "http://www.drscheme.org/a")] has a
+the result of @scheme[(string->url "http://racket-lang.org/a")] has a
@scheme[path] field with only the string @scheme["a"].
When a @scheme["file"] URL is represented by a @scheme[url] structure,
diff --git a/collects/scribblings/scribble/core.scrbl b/collects/scribblings/scribble/core.scrbl
index 321e14a798..4a2a49b8e3 100644
--- a/collects/scribblings/scribble/core.scrbl
+++ b/collects/scribblings/scribble/core.scrbl
@@ -332,8 +332,8 @@ The recognized @tech{style properties} are as follows:
string @tt{id} attribute of the @tt{body} tag; this style can
be set separately for parts that start different HTML pages,
otherwise it is effectively inherited by sub-parts; the
- default is @racket["scribble-plt-scheme.org"], but
- @exec{setup-plt} installs @racket["doc-plt-scheme.org"] as the
+ default is @racket["scribble-racket-lang.org"], but
+ @exec{setup-plt} installs @racket["doc-racket-lang.org"] as the
@tt{id} for any document that it builds.}
]
diff --git a/collects/sirmail/pref.rkt b/collects/sirmail/pref.rkt
index 5151619c35..ea241e3bca 100644
--- a/collects/sirmail/pref.rkt
+++ b/collects/sirmail/pref.rkt
@@ -39,15 +39,15 @@
;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
- (preferences:set-default 'sirmail:mail-from "SirMail User - http://svn.plt-scheme.org/plt/trunk/collects/tests/mzscheme/benchmarks/common/ + http://git.racket-lang.org/plt/tree/HEAD:/collects/tests/racket/benchmarks/common/ diff --git a/collects/tests/racket/benchmarks/common/tabulate.rkt b/collects/tests/racket/benchmarks/common/tabulate.rkt index 320dfae1d6..bb9babf32b 100755 --- a/collects/tests/racket/benchmarks/common/tabulate.rkt +++ b/collects/tests/racket/benchmarks/common/tabulate.rkt @@ -376,8 +376,8 @@ exec racket -qu "$0" ${1+"$@"} (lambda (fastest n-fastest c-fastest relative-to base n-base c-base) `(tr (td ,(if (include-links) - `(a ((href ,(format (string-append "http://svn.plt-scheme.org/plt/trunk/collects/" - "tests/mzscheme/benchmarks/common/~a.sch") + `(a ((href ,(format (string-append "http://git.racket-lang.org/plt/tree/HEAD:/collects/" + "tests/racket/benchmarks/common/~a.sch") (car bm-run)))) ,(symbol->string (car bm-run))) (symbol->string (car bm-run)))) diff --git a/collects/tests/racket/head.rktl b/collects/tests/racket/head.rktl index f02736867c..d14790465e 100644 --- a/collects/tests/racket/head.rktl +++ b/collects/tests/racket/head.rktl @@ -3,42 +3,42 @@ ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; ;; -;; url.ss tests +;; net/head tests ;; (require net/head) (for-each (lambda (addr) - (test '("o.gu@plt-scheme.com") extract-addresses (car addr) 'address) - (test '("o.gu@plt-scheme.com" "o.gu@plt-scheme.com") extract-addresses + (test '("o.gu@racket-lang.com") extract-addresses (car addr) 'address) + (test '("o.gu@racket-lang.com" "o.gu@racket-lang.com") extract-addresses (format "~a, ~a" (car addr) (car addr)) 'address) (test (list (cdr addr)) extract-addresses (car addr) 'name) (for-each (lambda (addr2) (let ([two (format " ~a, \n\t~a" (car addr) (car addr2))]) - (test '("o.gu@plt-scheme.com" "s.gu@plt-scheme.org") extract-addresses two 'address) + (test '("o.gu@racket-lang.com" "s.gu@racket-lang.org") extract-addresses two 'address) (test (list (cdr addr) (cdr addr2)) extract-addresses two 'name))) - '(("s.gu@plt-scheme.org" . "s.gu@plt-scheme.org") - ("
| Welcome to the Racket Web Server-Find out more about writing servlets by reading the Continue tutorial in the Help Desk. -Find out more about the server by reading its reference manual in the Help Desk. +Find out more about writing servlets by reading the Continue tutorial in the Help Desk. +Find out more about the server by reading its reference manual in the Help Desk. Please replace this page with your favorite index page. diff --git a/src/lt/configure b/src/lt/configure index 4888ee11d2..e3f5aa6ed9 100755 --- a/src/lt/configure +++ b/src/lt/configure @@ -2,7 +2,7 @@ # Guess values for system-dependent variables and create Makefiles. # Generated by GNU Autoconf 2.59 for lt 1.0. # -# Report bugs to |
diff --git a/collects/racket/help.rkt b/collects/racket/help.rkt
index c99eb3de6d..ced0c758e8 100644
--- a/collects/racket/help.rkt
+++ b/collects/racket/help.rkt
@@ -46,7 +46,7 @@
(go-to-main-page))
;; Autoload utilities from help/help-utils; if it does not exists,
;; suggest using docs.plt-scheme.org.
(define-namespace-anchor anchor)
(define get-binding
@@ -65,7 +65,7 @@
'help
(string-append
"documentation system unavailable; "
- "try http://docs.plt-scheme.org/")))])
+ "try http://docs.racket-lang.org/")))])
(dynamic-require 'help/help-utils sym)))))
(define-syntax-rule (define-help-autoload id)
@@ -46,7 +46,7 @@
(go-to-main-page))
;; Autoload utilities from help/help-utils; if it does not exists,
-;; suggest using docs.plt-scheme.org.
+;; suggest using docs.racket-lang.org.
(define-namespace-anchor anchor)
(define get-binding